==> bootstrap-10.14.1.tgz: package/Sunglasses/Sunglasses.esm.js <==
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export const Sunglasses = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M8 7a1 1 0 00-1 1H6a2 2 0 114 0H9a1 1 0 00-1-1zM0 8a.5.5 0 01.5-.5h1v1h-1A.5.5 0 010 8zm15.5.5h-1v-1h1a.5.5 0 010 1z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M3 5a2 2 0 00-2 2v2a2 2 0 002 2h1a3 3 0 003-3V7a2 2 0 00-2-2H3zm0 1a1 1 0 00-1 1v.941c0 .264.356.348.474.112l.228-.457a2 2 0 01.894-.894l.457-.228C4.289 6.356 4.205 6 3.94 6H3z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M2.023 6.784C2.008 6.854 2 6.926 2 7v.941c0 .264.356.348.474.112l.228-.457a2 2 0 01.894-.894l.457-.228C4.289 6.356 4.205 6 3.94 6H3a1.001 1.001 0 00-.977.784zm3.146-.77A1.219 1.219 0 014.5 7.368l-.457.228a1 1 0 00-.447.447l-.228.457a1.22 1.22 0 01-1.354.669A1 1 0 003 10h1a2 2 0 002-2V7a1 1 0 00-.831-.986zM1 7a2 2 0 012-2h2a2 2 0 012 2v1a3 3 0 01-3 3H3a2 2 0 01-2-2V7z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M9 7a2 2 0 012-2h2a2 2 0 012 2v2a2 2 0 01-2 2h-1a3 3 0 01-3-3V7z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M13 6h-2a1 1 0 00-1 1v1a2 2 0 002 2h1a1 1 0 001-1V7a1 1 0 00-1-1zm-2-1a2 2 0 00-2 2v1a3 3 0 003 3h1a2 2 0 002-2V7a2 2 0 00-2-2h-2z"
  }));
});
Sunglasses.displayName = 'Sunglasses';
export const SunglassesDimensions = {
  height: 16,
  width: 16
};

==> bootstrap-10.15.1.tgz: package/Sunglasses/Sunglasses.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var Sunglasses = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 16 16"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M8 7a1 1 0 00-1 1H6a2 2 0 114 0H9a1 1 0 00-1-1zM0 8a.5.5 0 01.5-.5h1v1h-1A.5.5 0 010 8zm15.5.5h-1v-1h1a.5.5 0 010 1z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M3 5a2 2 0 00-2 2v2a2 2 0 002 2h1a3 3 0 003-3V7a2 2 0 00-2-2H3zm0 1a1 1 0 00-1 1v.941c0 .264.356.348.474.112l.228-.457a2 2 0 01.894-.894l.457-.228C4.289 6.356 4.205 6 3.94 6H3z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M2.023 6.784C2.008 6.854 2 6.926 2 7v.941c0 .264.356.348.474.112l.228-.457a2 2 0 01.894-.894l.457-.228C4.289 6.356 4.205 6 3.94 6H3a1.001 1.001 0 00-.977.784zm3.146-.77A1.219 1.219 0 014.5 7.368l-.457.228a1 1 0 00-.447.447l-.228.457a1.22 1.22 0 01-1.354.669A1 1 0 003 10h1a2 2 0 002-2V7a1 1 0 00-.831-.986zM1 7a2 2 0 012-2h2a2 2 0 012 2v1a3 3 0 01-3 3H3a2 2 0 01-2-2V7z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M9 7a2 2 0 012-2h2a2 2 0 012 2v2a2 2 0 01-2 2h-1a3 3 0 01-3-3V7z"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M13 6h-2a1 1 0 00-1 1v1a2 2 0 002 2h1a1 1 0 001-1V7a1 1 0 00-1-1zm-2-1a2 2 0 00-2 2v1a3 3 0 003 3h1a2 2 0 002-2V7a2 2 0 00-2-2h-2z"
  }));
});
Sunglasses.displayName = 'Sunglasses';
export var SunglassesDimensions = {
  height: 16,
  width: 16
};
